@@ -1,6 +1,5 @@
 /*
- *  Copyright (c) 2014, Peter Haag
- *  Copyright (c) 2009, Peter Haag
+ *  Copyright (c) 2009-2020, Peter Haag
  *  Copyright (c) 2004-2008, SWITCH - Teleinformatikdienste fuer Lehre und Forschung
  *  All rights reserved.
  *  
@@ -28,13 +27,6 @@
  *  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
  *  POSSIBILITY OF SUCH DAMAGE.
  *  
- *  $Author: haag $
- *
- *  $Id:$
- *
- *  $LastChangedRevision: 48 $
- *	
- *
  */
 
 #include "config.h"
@@ -59,18 +51,14 @@
 #include <stdint.h>
 #endif
 
+#include "util.h"
+#include "nfdump.h"
 #include "nffile.h"
 #include "nfx.h"
-#include "util.h"
+#include "exporter.h"
 #include "flist.h"
 #include "panonymizer.h"
 
-#if ( SIZEOF_VOID_P == 8 )
-typedef uint64_t    pointer_addr_t;
-#else
-typedef uint32_t    pointer_addr_t;
-#endif
-
 // module limited globals
 extension_map_list_t *extension_map_list;
 
@@ -90,7 +78,7 @@ static void process_data(void *wfile);
 static void usage(char *name) {
 		printf("usage %s [options] \n"
 					"-h\t\tthis text you see right here\n"
-					"-K <key>\tAnonymize IP addressses using CryptoPAn with key <key>.\n"
+					"-K <key>\tAnonymize IP addresses using CryptoPAn with key <key>.\n"
 					"-r\t\tread input from file\n"
 					"-M <expr>\tRead input from multiple directories.\n"
 					"-R <expr>\tRead input from sequence of files.\n"
@@ -106,18 +94,18 @@ int		i;
 	if ( (master_record->flags & FLAG_IPV6_ADDR) != 0 )	{ // IPv6
 		// IPv6
 		uint64_t    anon_ip[2];
-		anonymize_v6(master_record->v6.srcaddr, anon_ip);
-		master_record->v6.srcaddr[0] = anon_ip[0];
-		master_record->v6.srcaddr[1] = anon_ip[1];
+		anonymize_v6(master_record->V6.srcaddr, anon_ip);
+		master_record->V6.srcaddr[0] = anon_ip[0];
+		master_record->V6.srcaddr[1] = anon_ip[1];
     
-		anonymize_v6(master_record->v6.dstaddr, anon_ip);
-		master_record->v6.dstaddr[0] = anon_ip[0];
-		master_record->v6.dstaddr[1] = anon_ip[1];
+		anonymize_v6(master_record->V6.dstaddr, anon_ip);
+		master_record->V6.dstaddr[0] = anon_ip[0];
+		master_record->V6.dstaddr[1] = anon_ip[1];
 
 	} else { 	
 		// IPv4
-		master_record->v4.srcaddr = anonymize(master_record->v4.srcaddr);
-		master_record->v4.dstaddr = anonymize(master_record->v4.dstaddr);
+		master_record->V4.srcaddr = anonymize(master_record->V4.srcaddr);
+		master_record->V4.dstaddr = anonymize(master_record->V4.dstaddr);
 	}
 
 	// Process optional extensions
@@ -133,45 +121,45 @@ int		i;
 				master_record->dstas = 0;
 				break;
 			case EX_NEXT_HOP_v4:
-				master_record->ip_nexthop.v4 = anonymize(master_record->ip_nexthop.v4);
+				master_record->ip_nexthop.V4 = anonymize(master_record->ip_nexthop.V4);
 				break;
 			case EX_NEXT_HOP_v6: {
 				uint64_t    anon_ip[2];
-				anonymize_v6(master_record->ip_nexthop.v6, anon_ip);
-				master_record->ip_nexthop.v6[0] = anon_ip[0];
-				master_record->ip_nexthop.v6[1] = anon_ip[1];
+				anonymize_v6(master_record->ip_nexthop.V6, anon_ip);
+				master_record->ip_nexthop.V6[0] = anon_ip[0];
+				master_record->ip_nexthop.V6[1] = anon_ip[1];
 				} break;
 			case EX_NEXT_HOP_BGP_v4: 
-				master_record->bgp_nexthop.v4 = anonymize(master_record->bgp_nexthop.v4);
+				master_record->bgp_nexthop.V4 = anonymize(master_record->bgp_nexthop.V4);
 				break;
 			case EX_NEXT_HOP_BGP_v6: {
 				uint64_t    anon_ip[2];
-				anonymize_v6(master_record->bgp_nexthop.v6, anon_ip);
-				master_record->bgp_nexthop.v6[0] = anon_ip[0];
-				master_record->bgp_nexthop.v6[1] = anon_ip[1];
+				anonymize_v6(master_record->bgp_nexthop.V6, anon_ip);
+				master_record->bgp_nexthop.V6[0] = anon_ip[0];
+				master_record->bgp_nexthop.V6[1] = anon_ip[1];
 				} break;
 			case EX_ROUTER_IP_v4:
-				master_record->ip_router.v4 = anonymize(master_record->ip_router.v4);
+				master_record->ip_router.V4 = anonymize(master_record->ip_router.V4);
 				break;
 			case EX_ROUTER_IP_v6: {
 				uint64_t    anon_ip[2];
-				anonymize_v6(master_record->ip_router.v6, anon_ip);
-				master_record->ip_router.v6[0] = anon_ip[0];
-				master_record->ip_router.v6[1] = anon_ip[1];
+				anonymize_v6(master_record->ip_router.V6, anon_ip);
+				master_record->ip_router.V6[0] = anon_ip[0];
+				master_record->ip_router.V6[1] = anon_ip[1];
 				} break;
 #ifdef NSEL
 			case EX_NSEL_XLATE_IP_v4:
-				master_record->xlate_src_ip.v4 = anonymize(master_record->xlate_src_ip.v4);
-				master_record->xlate_dst_ip.v4 = anonymize(master_record->xlate_dst_ip.v4);
+				master_record->xlate_src_ip.V4 = anonymize(master_record->xlate_src_ip.V4);
+				master_record->xlate_dst_ip.V4 = anonymize(master_record->xlate_dst_ip.V4);
 				break;
 			case EX_NSEL_XLATE_IP_v6: {
 				uint64_t    anon_ip[2];
-				anonymize_v6(master_record->xlate_src_ip.v6, anon_ip);
-				master_record->xlate_src_ip.v6[0] = anon_ip[0];
-				master_record->xlate_src_ip.v6[1] = anon_ip[1];
-				anonymize_v6(master_record->xlate_dst_ip.v6, anon_ip);
-				master_record->xlate_dst_ip.v6[0] = anon_ip[0];
-				master_record->xlate_dst_ip.v6[1] = anon_ip[1];
+				anonymize_v6(master_record->xlate_src_ip.V6, anon_ip);
+				master_record->xlate_src_ip.V6[0] = anon_ip[0];
+				master_record->xlate_src_ip.V6[1] = anon_ip[1];
+				anonymize_v6(master_record->xlate_dst_ip.V6, anon_ip);
+				master_record->xlate_dst_ip.V6[0] = anon_ip[0];
+				master_record->xlate_dst_ip.V6[1] = anon_ip[1];
 				} break;
 #endif
 		}
@@ -187,10 +175,6 @@ nffile_t			*nffile_r;
 nffile_t			*nffile_w;
 int 		i, done, ret, cnt, verbose;
 char		outfile[MAXPATHLEN], *cfile;
-#ifdef COMPAT15
-int	v1_map_done = 0;
-#endif
-
 
 	setbuf(stderr, NULL);
 	cnt 	= 1;
@@ -310,52 +294,20 @@ int	v1_map_done = 0;
 				} break; // not really needed
 		}
 
-#ifdef COMPAT15
-		if ( nffile_r->block_header->id == DATA_BLOCK_TYPE_1 ) {
-			common_record_v1_t *v1_record = (common_record_v1_t *)nffile_r->buff_ptr;
-			// create an extension map for v1 blocks
-			if ( v1_map_done == 0 ) {
-				extension_map_t *map = malloc(sizeof(extension_map_t) + 2 * sizeof(uint16_t) );
-				if ( ! map ) {
-					LogError("malloc() error in %s line %d: %s\n", __FILE__, __LINE__, strerror(errno) );
-					exit(255);
-				}
-				map->type 	= ExtensionMapType;
-				map->size 	= sizeof(extension_map_t) + 2 * sizeof(uint16_t);
-				map->map_id = 0;
-				map->ex_id[0]  = EX_IO_SNMP_2;
-				map->ex_id[1]  = EX_AS_2;
-				map->ex_id[2]  = 0;
-
-				Insert_Extension_Map(extension_map_list, map);
-				AppendToBuffer(nffile_w, (void *)map, map->size);
-
-				v1_map_done = 1;
-			}
-
-			// convert the records to v2
-			for ( i=0; i < nffile_r->block_header->NumRecords; i++ ) {
-				common_record_t *v2_record = (common_record_t *)v1_record;
-				Convert_v1_to_v2((void *)v1_record);
-				// now we have a v2 record -> use size of v2_record->size
-				v1_record = (common_record_v1_t *)((pointer_addr_t)v1_record + v2_record->size);
-			}
-			nffile_r->block_header->id = DATA_BLOCK_TYPE_2;
-		}
-#endif
-
-		if ( nffile_r->block_header->id == Large_BLOCK_Type ) {
-			// skip
-			continue;
-		}
-
 		if ( nffile_r->block_header->id != DATA_BLOCK_TYPE_2 ) {
 			fprintf(stderr, "Can't process block type %u. Skip block.\n", nffile_r->block_header->id);
 			continue;
 		}
 
 		flow_record = nffile_r->buff_ptr;
+		uint32_t sumSize = 0;
 		for ( i=0; i < nffile_r->block_header->NumRecords; i++ ) {
+			if ( (sumSize + flow_record->size) > ret ) {
+				LogError("Corrupt data file. Inconsistent block size in %s line %d\n", __FILE__, __LINE__);
+				exit(255);
+			}
+			sumSize += flow_record->size;
+
 			switch ( flow_record->type ) { 
 				case CommonRecordType: {
 					uint32_t map_id = flow_record->ext_map;
@@ -375,14 +327,20 @@ int	v1_map_done = 0;
 				case ExtensionMapType: {
 					extension_map_t *map = (extension_map_t *)flow_record;
 
-					if ( Insert_Extension_Map(extension_map_list, map) ) {
-					 	// flush new map
-					} // else map already known and flushed
-					AppendToBuffer(nffile_w, (void *)map, map->size);
-
+					int ret = Insert_Extension_Map(extension_map_list, map);
+					switch (ret) {
+						case 0:
+							break; // map already known and flushed
+						case 1:
+							AppendToBuffer(nffile_w, (void *)map, map->size);
+							break;
+						default:
+							LogError("Corrupt data file. Unable to decode at %s line %d\n", __FILE__, __LINE__);
+							exit(255);
+					}
 					} break; 
-				case ExporterRecordType:
-				case SamplerRecordype:
+				case LegacyRecordType1:
+				case LegacyRecordType2:
 				case ExporterInfoRecordType:
 				case ExporterStatRecordType:
 				case SamplerInfoRecordype:
@@ -438,7 +396,7 @@ char		CryptoPAnKey[32];
 				PAnonymizer_Init((uint8_t *)CryptoPAnKey);
 				break;
 			case 'L':
-				if ( !InitLog("argv[0]", optarg) )
+				if ( !InitLog(0, "argv[0]", optarg, 0) )
 					exit(255);
 				break;
 			case 'r':
