@@ -1,8 +1,8 @@
-/* A Bison parser, made by GNU Bison 2.7.12-4996.  */
+/* A Bison parser, made by GNU Bison 2.7.  */
 
 /* Bison implementation for Yacc-like parsers in C
    
-      Copyright (C) 1984, 1989-1990, 2000-2013 Free Software Foundation, Inc.
+      Copyright (C) 1984, 1989-1990, 2000-2012 Free Software Foundation, Inc.
    
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -44,7 +44,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "2.7.12-4996"
+#define YYBISON_VERSION "2.7"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -73,9 +73,11 @@
 #line 30 "ffilter/ffilter_gram.y"
 
 	#include <stdio.h>
+    #include <string.h>
+
 	#include "ffilter.h"
 	#include "ffilter_internal.h"
-	#include <string.h>
+	#include "ffilter_gram.h"
 
 	#define YY_EXTRA_TYPE ff_t
 
@@ -86,7 +88,7 @@
 
 
 /* Line 371 of yacc.c  */
-#line 90 "ffilter/ffilter_gram.c"
+#line 92 "ffilter/ffilter_gram.c"
 
 # ifndef YY_NULL
 #  if defined __cplusplus && 201103L <= __cplusplus
@@ -131,17 +133,15 @@ extern int ff2_debug;
      LT = 264,
      GT = 265,
      ISSET = 266,
-     LP = 267,
-     RP = 268,
-     LPS = 269,
-     RPS = 270,
-     IN = 271,
-     STRING = 272,
-     DIR = 273,
-     BIDIR_AND = 274,
-     BIDIR_OR = 275,
-     DIR_DIR_MAC = 276,
-     BAD_TOKEN = 277
+     IN = 267,
+     IDENT = 268,
+     STRING = 269,
+     QUOTED = 270,
+     DIR = 271,
+     DIR_2 = 272,
+     PAIR_AND = 273,
+     PAIR_OR = 274,
+     BAD_TOKEN = 275
    };
 #endif
 /* Tokens.  */
@@ -154,17 +154,15 @@ extern int ff2_debug;
 #define LT 264
 #define GT 265
 #define ISSET 266
-#define LP 267
-#define RP 268
-#define LPS 269
-#define RPS 270
-#define IN 271
-#define STRING 272
-#define DIR 273
-#define BIDIR_AND 274
-#define BIDIR_OR 275
-#define DIR_DIR_MAC 276
-#define BAD_TOKEN 277
+#define IN 267
+#define IDENT 268
+#define STRING 269
+#define QUOTED 270
+#define DIR 271
+#define DIR_2 272
+#define PAIR_AND 273
+#define PAIR_OR 274
+#define BAD_TOKEN 275
 
 
 
@@ -172,7 +170,7 @@ extern int ff2_debug;
 typedef union YYSTYPE
 {
 /* Line 387 of yacc.c  */
-#line 45 "ffilter/ffilter_gram.y"
+#line 47 "ffilter/ffilter_gram.y"
 
 	uint64_t	t_uint;
 	double		t_double;
@@ -181,7 +179,7 @@ typedef union YYSTYPE
 
 
 /* Line 387 of yacc.c  */
-#line 185 "ffilter/ffilter_gram.c"
+#line 183 "ffilter/ffilter_gram.c"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
@@ -208,7 +206,7 @@ int ff2_parse ();
 /* Copy the second part of user declarations.  */
 
 /* Line 390 of yacc.c  */
-#line 212 "ffilter/ffilter_gram.c"
+#line 210 "ffilter/ffilter_gram.c"
 
 #ifdef short
 # undef short
@@ -269,14 +267,6 @@ typedef short int yytype_int16;
 # endif
 #endif
 
-#ifndef __attribute__
-/* This feature is available in gcc versions 2.5 and later.  */
-# if (! defined __GNUC__ || __GNUC__ < 2 \
-      || (__GNUC__ == 2 && __GNUC_MINOR__ < 5))
-#  define __attribute__(Spec) /* empty */
-# endif
-#endif
-
 /* Suppress unused-variable warnings by "using" E.  */
 #if ! defined lint || defined __GNUC__
 # define YYUSE(E) ((void) (E))
@@ -284,7 +274,6 @@ typedef short int yytype_int16;
 # define YYUSE(E) /* empty */
 #endif
 
-
 /* Identity function, used to suppress warnings about constant conditions.  */
 #ifndef lint
 # define YYID(N) (N)
@@ -435,22 +424,22 @@ union yyalloc
 #endif /* !YYCOPY_NEEDED */
 
 /* YYFINAL -- State number of the termination state.  */
-#define YYFINAL  20
+#define YYFINAL  22
 /* YYLAST -- Last index in YYTABLE.  */
-#define YYLAST   41
+#define YYLAST   55
 
 /* YYNTOKENS -- Number of terminals.  */
-#define YYNTOKENS  23
+#define YYNTOKENS  25
 /* YYNNTS -- Number of nonterminals.  */
-#define YYNNTS  7
+#define YYNNTS  9
 /* YYNRULES -- Number of rules.  */
-#define YYNRULES  26
+#define YYNRULES  32
 /* YYNRULES -- Number of states.  */
-#define YYNSTATES  39
+#define YYNSTATES  49
 
 /* YYTRANSLATE(YYLEX) -- Bison symbol number corresponding to YYLEX.  */
 #define YYUNDEFTOK  2
-#define YYMAXUTOK   277
+#define YYMAXUTOK   275
 
 #define YYTRANSLATE(YYX)						\
   ((unsigned int) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)
@@ -462,12 +451,12 @@ static const yytype_uint8 yytranslate[] =
        2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
        2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
        2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
+      21,    22,     2,     2,    23,     2,     2,     2,     2,     2,
        2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
        2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
        2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
        2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
-       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
-       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
+       2,     2,     2,    24,     2,     2,     2,     2,     2,     2,
        2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
        2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
        2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
@@ -485,7 +474,7 @@ static const yytype_uint8 yytranslate[] =
        2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
        2,     2,     2,     2,     2,     2,     1,     2,     3,     4,
        5,     6,     7,     8,     9,    10,    11,    12,    13,    14,
-      15,    16,    17,    18,    19,    20,    21,    22
+      15,    16,    17,    18,    19,    20
 };
 
 #if YYDEBUG
@@ -493,29 +482,33 @@ static const yytype_uint8 yytranslate[] =
    YYRHS.  */
 static const yytype_uint8 yyprhs[] =
 {
-       0,     0,     3,     5,     6,     8,    11,    14,    17,    20,
-      22,    25,    27,    30,    34,    38,    42,    44,    47,    51,
-      55,    58,    61,    63,    65,    67,    69
+       0,     0,     3,     5,     6,     8,    11,    14,    18,    21,
+      24,    26,    28,    30,    33,    35,    37,    39,    42,    46,
+      50,    54,    57,    61,    65,    67,    71,    74,    77,    79,
+      81,    83,    85
 };
 
 /* YYRHS -- A `-1'-separated list of the rules' RHS.  */
 static const yytype_int8 yyrhs[] =
 {
-      24,     0,    -1,    27,    -1,    -1,    17,    -1,    18,    17,
-      -1,    20,    17,    -1,    19,    17,    -1,    21,    17,    -1,
-      17,    -1,    17,    17,    -1,     6,    -1,     5,    27,    -1,
-      27,     3,    27,    -1,    27,     4,    27,    -1,    12,    27,
-      13,    -1,    25,    -1,     7,    25,    -1,    25,    29,    26,
-      -1,    25,    16,    28,    -1,    17,    28,    -1,    17,    15,
-      -1,    11,    -1,     8,    -1,     9,    -1,    10,    -1,    -1
+      26,     0,    -1,    31,    -1,    -1,    13,    -1,    16,    13,
+      -1,    17,    13,    -1,    17,    16,    13,    -1,    19,    13,
+      -1,    18,    13,    -1,    13,    -1,    14,    -1,    30,    -1,
+      28,    28,    -1,    28,    -1,    15,    -1,     6,    -1,     5,
+      31,    -1,    31,     3,    31,    -1,    31,     4,    31,    -1,
+      21,    31,    22,    -1,     7,    27,    -1,    27,    33,    29,
+      -1,    27,    12,    32,    -1,    13,    -1,    30,    23,    32,
+      -1,    30,    32,    -1,    30,    24,    -1,    11,    -1,     8,
+      -1,     9,    -1,    10,    -1,    -1
 };
 
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const yytype_uint8 yyrline[] =
 {
-       0,    70,    70,    71,    75,    76,    77,    78,    79,    83,
-      84,    88,    89,    90,    91,    92,    93,   110,   111,   112,
-     116,   117,   121,   122,   123,   124,   125
+       0,    73,    73,    74,    78,    79,    80,    81,    82,    83,
+      87,    88,    91,    92,    95,    96,   100,   101,   102,   103,
+     104,   105,   106,   107,   108,   112,   113,   114,   118,   119,
+     120,   121,   122
 };
 #endif
 
@@ -525,9 +518,10 @@ static const yytype_uint8 yyrline[] =
 static const char *const yytname[] =
 {
   "$end", "error", "$undefined", "AND", "OR", "NOT", "ANY", "EXIST", "EQ",
-  "LT", "GT", "ISSET", "LP", "RP", "LPS", "RPS", "IN", "STRING", "DIR",
-  "BIDIR_AND", "BIDIR_OR", "DIR_DIR_MAC", "BAD_TOKEN", "$accept", "filter",
-  "field", "value", "expr", "list", "cmp", YY_NULL
+  "LT", "GT", "ISSET", "IN", "IDENT", "STRING", "QUOTED", "DIR", "DIR_2",
+  "PAIR_AND", "PAIR_OR", "BAD_TOKEN", "'('", "')'", "','", "']'",
+  "$accept", "filter", "field", "string", "value", "consistent_val",
+  "expr", "list", "cmp", YY_NULL
 };
 #endif
 
@@ -538,24 +532,26 @@ static const yytype_uint16 yytoknum[] =
 {
        0,   256,   257,   258,   259,   260,   261,   262,   263,   264,
      265,   266,   267,   268,   269,   270,   271,   272,   273,   274,
-     275,   276,   277
+     275,    40,    41,    44,    93
 };
 # endif
 
 /* YYR1[YYN] -- Symbol number of symbol that rule YYN derives.  */
 static const yytype_uint8 yyr1[] =
 {
-       0,    23,    24,    24,    25,    25,    25,    25,    25,    26,
-      26,    27,    27,    27,    27,    27,    27,    27,    27,    27,
-      28,    28,    29,    29,    29,    29,    29
+       0,    25,    26,    26,    27,    27,    27,    27,    27,    27,
+      28,    28,    29,    29,    30,    30,    31,    31,    31,    31,
+      31,    31,    31,    31,    31,    32,    32,    32,    33,    33,
+      33,    33,    33
 };
 
 /* YYR2[YYN] -- Number of symbols composing right hand side of rule YYN.  */
 static const yytype_uint8 yyr2[] =
 {
-       0,     2,     1,     0,     1,     2,     2,     2,     2,     1,
-       2,     1,     2,     3,     3,     3,     1,     2,     3,     3,
-       2,     2,     1,     1,     1,     1,     0
+       0,     2,     1,     0,     1,     2,     2,     3,     2,     2,
+       1,     1,     1,     2,     1,     1,     1,     2,     3,     3,
+       3,     2,     3,     3,     1,     3,     2,     2,     1,     1,
+       1,     1,     0
 };
 
 /* YYDEFACT[STATE-NAME] -- Default reduction number in state STATE-NUM.
@@ -563,71 +559,76 @@ static const yytype_uint8 yyr2[] =
    means the default is an error.  */
 static const yytype_uint8 yydefact[] =
 {
-       3,     0,    11,     0,     0,     4,     0,     0,     0,     0,
-       0,    16,     2,    12,    17,     0,     5,     7,     6,     8,
-       1,    23,    24,    25,    22,     0,     0,     0,     0,    15,
-       0,    19,     9,    18,    13,    14,    21,    20,    10
+       3,     0,    16,     0,     4,     0,     0,     0,     0,     0,
+       0,    32,     2,    17,     4,    21,     5,     6,     0,     9,
+       8,     0,     1,    29,    30,    31,    28,     0,     0,     0,
+       0,     7,    20,    10,    11,    15,    14,     0,    23,    14,
+      22,    12,    18,    19,     0,    27,    26,    13,    25
 };
 
 /* YYDEFGOTO[NTERM-NUM].  */
 static const yytype_int8 yydefgoto[] =
 {
-      -1,    10,    11,    33,    12,    31,    26
+      -1,    10,    11,    36,    40,    37,    12,    38,    28
 };
 
 /* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
    STATE-NUM.  */
-#define YYPACT_NINF -16
+#define YYPACT_NINF -35
 static const yytype_int8 yypact[] =
 {
-       0,     0,   -16,    15,     0,   -16,   -13,    -8,    11,    12,
-      16,    14,    10,   -16,   -16,    -2,   -16,   -16,   -16,   -16,
-     -16,   -16,   -16,   -16,   -16,    20,    21,     0,     0,   -16,
-      -7,   -16,    22,   -16,   -16,    37,   -16,   -16,   -16
+      14,    14,   -35,    -2,     1,     5,    -4,     9,    11,    14,
+      26,    31,    41,   -35,   -35,   -35,   -35,   -35,    21,   -35,
+     -35,     3,   -35,   -35,   -35,   -35,   -35,    35,    35,    14,
+      14,   -35,   -35,   -35,   -35,   -35,   -35,    23,   -35,    38,
+     -35,   -35,   -35,    50,    35,   -35,   -35,   -35,   -35
 };
 
 /* YYPGOTO[NTERM-NUM].  */
 static const yytype_int8 yypgoto[] =
 {
-     -16,   -16,    38,   -16,    -1,   -15,   -16
+     -35,   -35,    51,   -26,   -35,    27,    -1,   -34,   -35
 };
 
 /* YYTABLE[YYPACT[STATE-NUM]].  What to do in state STATE-NUM.  If
    positive, shift that token.  If negative, reduce the rule which
    number is the opposite.  If YYTABLE_NINF, syntax error.  */
-#define YYTABLE_NINF -27
+#define YYTABLE_NINF -25
 static const yytype_int8 yytable[] =
 {
-      13,    27,    28,    15,    16,     1,     2,     3,    36,    17,
-      30,    29,     4,    27,    28,    37,    20,     5,     6,     7,
-       8,     9,    21,    22,    23,    24,    34,    35,    18,    19,
-      25,   -26,     5,     6,     7,     8,     9,    30,    32,    38,
-      27,    14
+      13,   -24,    39,    46,   -24,   -24,    29,    30,    21,    17,
+      48,    14,    18,    47,     5,     6,     7,     8,    16,     1,
+       2,     3,    19,   -24,    20,    32,    22,     4,    42,    43,
+       5,     6,     7,     8,    31,     9,    33,    34,    35,    23,
+      24,    25,    26,    27,    29,    30,    44,    45,    33,    34,
+      35,    33,    34,    29,    15,    41
 };
 
 #define yypact_value_is_default(Yystate) \
-  (!!((Yystate) == (-16)))
+  (!!((Yystate) == (-35)))
 
 #define yytable_value_is_error(Yytable_value) \
   YYID (0)
 
 static const yytype_uint8 yycheck[] =
 {
-       1,     3,     4,     4,    17,     5,     6,     7,    15,    17,
-      17,    13,    12,     3,     4,    30,     0,    17,    18,    19,
-      20,    21,     8,     9,    10,    11,    27,    28,    17,    17,
-      16,    17,    17,    18,    19,    20,    21,    17,    17,    17,
-       3,     3
+       1,     0,    28,    37,     3,     4,     3,     4,     9,    13,
+      44,    13,    16,    39,    16,    17,    18,    19,    13,     5,
+       6,     7,    13,    22,    13,    22,     0,    13,    29,    30,
+      16,    17,    18,    19,    13,    21,    13,    14,    15,     8,
+       9,    10,    11,    12,     3,     4,    23,    24,    13,    14,
+      15,    13,    14,     3,     3,    28
 };
 
 /* YYSTOS[STATE-NUM] -- The (internal number of the) accessing
    symbol of state STATE-NUM.  */
 static const yytype_uint8 yystos[] =
 {
-       0,     5,     6,     7,    12,    17,    18,    19,    20,    21,
-      24,    25,    27,    27,    25,    27,    17,    17,    17,    17,
-       0,     8,     9,    10,    11,    16,    29,     3,     4,    13,
-      17,    28,    17,    26,    27,    27,    15,    28,    17
+       0,     5,     6,     7,    13,    16,    17,    18,    19,    21,
+      26,    27,    31,    31,    13,    27,    13,    13,    16,    13,
+      13,    31,     0,     8,     9,    10,    11,    12,    33,     3,
+       4,    13,    22,    13,    14,    15,    28,    30,    32,    28,
+      29,    30,    31,    31,    23,    24,    32,    28,    32
 };
 
 #define yyerrok		(yyerrstatus = 0)
@@ -749,7 +750,11 @@ yy_symbol_value_print (yyoutput, yytype, yyvaluep, scanner, filter)
 # else
   YYUSE (yyoutput);
 # endif
-  YYUSE (yytype);
+  switch (yytype)
+    {
+      default:
+        break;
+    }
 }
 
 
@@ -1147,7 +1152,12 @@ yydestruct (yymsg, yytype, yyvaluep, scanner, filter)
     yymsg = "Deleting";
   YY_SYMBOL_PRINT (yymsg, yytype, yyvaluep, yylocationp);
 
-  YYUSE (yytype);
+  switch (yytype)
+    {
+
+      default:
+        break;
+    }
 }
 
 
@@ -1445,174 +1455,194 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-/* Line 1787 of yacc.c  */
-#line 70 "ffilter/ffilter_gram.y"
+/* Line 1792 of yacc.c  */
+#line 73 "ffilter/ffilter_gram.y"
     { filter->root = (yyvsp[(1) - (1)].node); }
     break;
 
   case 3:
-/* Line 1787 of yacc.c  */
-#line 71 "ffilter/ffilter_gram.y"
+/* Line 1792 of yacc.c  */
+#line 74 "ffilter/ffilter_gram.y"
     { filter->root = NULL; }
     break;
 
   case 4:
-/* Line 1787 of yacc.c  */
-#line 75 "ffilter/ffilter_gram.y"
+/* Line 1792 of yacc.c  */
+#line 78 "ffilter/ffilter_gram.y"
     { strncpy((yyval.string), (yyvsp[(1) - (1)].string), FF_MAX_STRING - 1); }
     break;
 
   case 5:
-/* Line 1787 of yacc.c  */
-#line 76 "ffilter/ffilter_gram.y"
-    { snprintf((yyval.string), FF_MAX_STRING - 1, "%s %s", (yyvsp[(1) - (2)].string), (yyvsp[(2) - (2)].string)); }
+/* Line 1792 of yacc.c  */
+#line 79 "ffilter/ffilter_gram.y"
+    { snprintf((yyval.string), FF_MAX_STRING - 1, "%s%s", (yyvsp[(1) - (2)].string), (yyvsp[(2) - (2)].string)); }
     break;
 
   case 6:
-/* Line 1787 of yacc.c  */
-#line 77 "ffilter/ffilter_gram.y"
-    { snprintf((yyval.string), FF_MAX_STRING - 1, "%c%s", '|', (yyvsp[(2) - (2)].string)); }
+/* Line 1792 of yacc.c  */
+#line 80 "ffilter/ffilter_gram.y"
+    { snprintf((yyval.string), FF_MAX_STRING - 1, "%s%s", (yyvsp[(1) - (2)].string), (yyvsp[(2) - (2)].string)); }
     break;
 
   case 7:
-/* Line 1787 of yacc.c  */
-#line 78 "ffilter/ffilter_gram.y"
-    { snprintf((yyval.string), FF_MAX_STRING - 1, "%c%s", '&', (yyvsp[(2) - (2)].string)); }
+/* Line 1792 of yacc.c  */
+#line 81 "ffilter/ffilter_gram.y"
+    { snprintf((yyval.string), FF_MAX_STRING - 1, "%s%s%s", (yyvsp[(1) - (3)].string),(yyvsp[(2) - (3)].string),(yyvsp[(3) - (3)].string)); }
     break;
 
   case 8:
-/* Line 1787 of yacc.c  */
-#line 79 "ffilter/ffilter_gram.y"
-    { snprintf((yyval.string), FF_MAX_STRING - 1, "%s %s", (yyvsp[(1) - (2)].string), (yyvsp[(2) - (2)].string)); }
+/* Line 1792 of yacc.c  */
+#line 82 "ffilter/ffilter_gram.y"
+    { snprintf((yyval.string), FF_MAX_STRING - 1, "%c%s", '|', (yyvsp[(2) - (2)].string)); }
     break;
 
   case 9:
-/* Line 1787 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 83 "ffilter/ffilter_gram.y"
-    { strncpy((yyval.string), (yyvsp[(1) - (1)].string), FF_MAX_STRING - 1); }
+    { snprintf((yyval.string), FF_MAX_STRING - 1, "%c%s", '&', (yyvsp[(2) - (2)].string)); }
     break;
 
   case 10:
-/* Line 1787 of yacc.c  */
-#line 84 "ffilter/ffilter_gram.y"
-    { snprintf((yyval.string), FF_MAX_STRING - 1, "%s %s", (yyvsp[(1) - (2)].string), (yyvsp[(2) - (2)].string)); }
+/* Line 1792 of yacc.c  */
+#line 87 "ffilter/ffilter_gram.y"
+    { strncpy((yyval.string), (yyvsp[(1) - (1)].string), FF_MAX_STRING - 1); /*TRY not to copy, only pass pointer*/ }
     break;
 
   case 11:
-/* Line 1787 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 88 "ffilter/ffilter_gram.y"
-    { (yyval.node) = ff_new_node(scanner, filter, NULL, FF_OP_YES, NULL); if ((yyval.node) == NULL) { YYABORT; }; }
+    { strncpy((yyval.string), (yyvsp[(1) - (1)].string), FF_MAX_STRING - 1); }
     break;
 
   case 12:
-/* Line 1787 of yacc.c  */
-#line 89 "ffilter/ffilter_gram.y"
-    { (yyval.node) = ff_new_node(scanner, filter, NULL, FF_OP_NOT, (yyvsp[(2) - (2)].node)); if ((yyval.node) == NULL) { YYABORT; }; }
+/* Line 1792 of yacc.c  */
+#line 91 "ffilter/ffilter_gram.y"
+    { strncpy((yyval.string), (yyvsp[(1) - (1)].string), FF_MAX_STRING - 1); }
     break;
 
   case 13:
-/* Line 1787 of yacc.c  */
-#line 90 "ffilter/ffilter_gram.y"
-    { (yyval.node) = ff_new_node(scanner, filter, (yyvsp[(1) - (3)].node), FF_OP_AND, (yyvsp[(3) - (3)].node)); if ((yyval.node) == NULL) { YYABORT; }; }
+/* Line 1792 of yacc.c  */
+#line 92 "ffilter/ffilter_gram.y"
+    { snprintf((yyval.string), FF_MAX_STRING - 1, "%s %s", (yyvsp[(1) - (2)].string), (yyvsp[(2) - (2)].string)); }
     break;
 
   case 14:
-/* Line 1787 of yacc.c  */
-#line 91 "ffilter/ffilter_gram.y"
-    { (yyval.node) = ff_new_node(scanner, filter, (yyvsp[(1) - (3)].node), FF_OP_OR, (yyvsp[(3) - (3)].node)); if ((yyval.node) == NULL) { YYABORT; }; }
+/* Line 1792 of yacc.c  */
+#line 95 "ffilter/ffilter_gram.y"
+    { strncpy((yyval.string), (yyvsp[(1) - (1)].string), FF_MAX_STRING - 1); }
     break;
 
   case 15:
-/* Line 1787 of yacc.c  */
-#line 92 "ffilter/ffilter_gram.y"
-    { (yyval.node) = (yyvsp[(2) - (3)].node); }
+/* Line 1792 of yacc.c  */
+#line 96 "ffilter/ffilter_gram.y"
+    { (yyvsp[(1) - (1)].string)[strlen((yyvsp[(1) - (1)].string))-1] = 0; snprintf((yyval.string), FF_MAX_STRING - 1, "%s", &(yyvsp[(1) - (1)].string)[1]); /*Dequote*/}
     break;
 
   case 16:
-/* Line 1787 of yacc.c  */
-#line 93 "ffilter/ffilter_gram.y"
-    { struct { char* name; char* field; char* cnst; } const_info[] =
-                        	{
-                            	{"inet", "inet", "4"},
-                        		{"inet6", "inet", "6"},
-                        		{"ipv4", "inet", "4"},
-                        		{"ipv6", "inet", "6"},
-                        		{NULL,NULL,NULL}
-                        	};
-                        	int x;
-                        	for(x = 0; const_info[x].name; x++){
-                        		if (!strcmp((yyvsp[(1) - (1)].string), const_info[x].name)){
-                        			(yyval.node) = ff_new_leaf(scanner, filter, const_info[x].field, FF_OP_EQ, const_info[x].cnst); if ((yyval.node) == NULL) { YYABORT; }
-                        			break;
-                        		}
-                        	}
-                        	if (!const_info[x].name) { YYABORT; };
-                        }
+/* Line 1792 of yacc.c  */
+#line 100 "ffilter/ffilter_gram.y"
+    { (yyval.node) = ff_new_node(scanner, filter, NULL, FF_OP_YES, NULL); if ((yyval.node) == NULL) { YYABORT; }; }
     break;
 
   case 17:
-/* Line 1787 of yacc.c  */
-#line 110 "ffilter/ffilter_gram.y"
-    { (yyval.node) = ff_new_leaf(scanner, filter, (yyvsp[(2) - (2)].string), FF_OP_EXIST, ""); if ((yyval.node) == NULL) { YYABORT; } }
+/* Line 1792 of yacc.c  */
+#line 101 "ffilter/ffilter_gram.y"
+    { (yyval.node) = ff_new_node(scanner, filter, NULL, FF_OP_NOT, (yyvsp[(2) - (2)].node)); if ((yyval.node) == NULL) { YYABORT; }; }
     break;
 
   case 18:
-/* Line 1787 of yacc.c  */
-#line 111 "ffilter/ffilter_gram.y"
-    { (yyval.node) = ff_new_leaf(scanner, filter, (yyvsp[(1) - (3)].string), (yyvsp[(2) - (3)].t_uint), (yyvsp[(3) - (3)].string)); if ((yyval.node) == NULL) { YYABORT; } }
+/* Line 1792 of yacc.c  */
+#line 102 "ffilter/ffilter_gram.y"
+    { (yyval.node) = ff_new_node(scanner, filter, (yyvsp[(1) - (3)].node), FF_OP_AND, (yyvsp[(3) - (3)].node)); if ((yyval.node) == NULL) { YYABORT; }; }
     break;
 
   case 19:
-/* Line 1787 of yacc.c  */
-#line 112 "ffilter/ffilter_gram.y"
-    { (yyval.node) = ff_new_leaf(scanner, filter, (yyvsp[(1) - (3)].string), FF_OP_IN, (yyvsp[(3) - (3)].node)); if ((yyval.node) == NULL) { YYABORT; } }
+/* Line 1792 of yacc.c  */
+#line 103 "ffilter/ffilter_gram.y"
+    { (yyval.node) = ff_new_node(scanner, filter, (yyvsp[(1) - (3)].node), FF_OP_OR, (yyvsp[(3) - (3)].node)); if ((yyval.node) == NULL) { YYABORT; }; }
     break;
 
   case 20:
-/* Line 1787 of yacc.c  */
-#line 116 "ffilter/ffilter_gram.y"
-    { (yyval.node) = ff_new_mval(scanner, filter, (yyvsp[(1) - (2)].string), FF_OP_EQ, (yyvsp[(2) - (2)].node)); if ((yyval.node) == NULL) { YYABORT; } }
+/* Line 1792 of yacc.c  */
+#line 104 "ffilter/ffilter_gram.y"
+    { (yyval.node) = (yyvsp[(2) - (3)].node); }
     break;
 
   case 21:
-/* Line 1787 of yacc.c  */
-#line 117 "ffilter/ffilter_gram.y"
-    { (yyval.node) = ff_new_mval(scanner, filter, (yyvsp[(1) - (2)].string), FF_OP_EQ, NULL); if ((yyval.node) == NULL) { YYABORT; } }
+/* Line 1792 of yacc.c  */
+#line 105 "ffilter/ffilter_gram.y"
+    { (yyval.node) = ff_new_leaf(scanner, filter, (yyvsp[(2) - (2)].string), FF_OP_EXIST, ""); if ((yyval.node) == NULL) { YYABORT; } }
     break;
 
   case 22:
-/* Line 1787 of yacc.c  */
-#line 121 "ffilter/ffilter_gram.y"
-    { (yyval.t_uint) = FF_OP_ISSET; }
+/* Line 1792 of yacc.c  */
+#line 106 "ffilter/ffilter_gram.y"
+    { (yyval.node) = ff_new_leaf(scanner, filter, (yyvsp[(1) - (3)].string), (yyvsp[(2) - (3)].t_uint), (yyvsp[(3) - (3)].string)); if ((yyval.node) == NULL) { YYABORT; } }
     break;
 
   case 23:
-/* Line 1787 of yacc.c  */
-#line 122 "ffilter/ffilter_gram.y"
-    { (yyval.t_uint) = FF_OP_EQ; }
+/* Line 1792 of yacc.c  */
+#line 107 "ffilter/ffilter_gram.y"
+    { (yyval.node) = ff_new_leaf(scanner, filter, (yyvsp[(1) - (3)].string), FF_OP_IN, (yyvsp[(3) - (3)].node)); if ((yyval.node) == NULL) { YYABORT; } }
     break;
 
   case 24:
-/* Line 1787 of yacc.c  */
-#line 123 "ffilter/ffilter_gram.y"
-    { (yyval.t_uint) = FF_OP_LT; }
+/* Line 1792 of yacc.c  */
+#line 108 "ffilter/ffilter_gram.y"
+    { (yyval.node) = ff_new_leaf(scanner, filter, (yyvsp[(1) - (1)].string), FF_OP_NOOP, ""); if ((yyval.node) == NULL) { YYABORT; } }
     break;
 
   case 25:
-/* Line 1787 of yacc.c  */
-#line 124 "ffilter/ffilter_gram.y"
-    { (yyval.t_uint) = FF_OP_GT; }
+/* Line 1792 of yacc.c  */
+#line 112 "ffilter/ffilter_gram.y"
+    { (yyval.node) = ff_new_mval(scanner, filter, (yyvsp[(1) - (3)].string), FF_OP_EQ, (yyvsp[(3) - (3)].node)); if ((yyval.node) == NULL) { YYABORT; } }
     break;
 
   case 26:
-/* Line 1787 of yacc.c  */
-#line 125 "ffilter/ffilter_gram.y"
+/* Line 1792 of yacc.c  */
+#line 113 "ffilter/ffilter_gram.y"
+    { (yyval.node) = ff_new_mval(scanner, filter, (yyvsp[(1) - (2)].string), FF_OP_EQ, (yyvsp[(2) - (2)].node)); if ((yyval.node) == NULL) { YYABORT; } }
+    break;
+
+  case 27:
+/* Line 1792 of yacc.c  */
+#line 114 "ffilter/ffilter_gram.y"
+    { (yyval.node) = ff_new_mval(scanner, filter, (yyvsp[(1) - (2)].string), FF_OP_EQ, NULL); if ((yyval.node) == NULL) { YYABORT; } }
+    break;
+
+  case 28:
+/* Line 1792 of yacc.c  */
+#line 118 "ffilter/ffilter_gram.y"
+    { (yyval.t_uint) = FF_OP_ISSET; }
+    break;
+
+  case 29:
+/* Line 1792 of yacc.c  */
+#line 119 "ffilter/ffilter_gram.y"
+    { (yyval.t_uint) = FF_OP_EQ; }
+    break;
+
+  case 30:
+/* Line 1792 of yacc.c  */
+#line 120 "ffilter/ffilter_gram.y"
+    { (yyval.t_uint) = FF_OP_LT; }
+    break;
+
+  case 31:
+/* Line 1792 of yacc.c  */
+#line 121 "ffilter/ffilter_gram.y"
+    { (yyval.t_uint) = FF_OP_GT; }
+    break;
+
+  case 32:
+/* Line 1792 of yacc.c  */
+#line 122 "ffilter/ffilter_gram.y"
     { (yyval.t_uint) = FF_OP_NOOP; }
     break;
 
 
-/* Line 1787 of yacc.c  */
-#line 1616 "ffilter/ffilter_gram.c"
+/* Line 1792 of yacc.c  */
+#line 1646 "ffilter/ffilter_gram.c"
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -1843,7 +1873,7 @@ yyreturn:
 }
 
 
-/* Line 2050 of yacc.c  */
-#line 128 "ffilter/ffilter_gram.y"
+/* Line 2055 of yacc.c  */
+#line 125 "ffilter/ffilter_gram.y"
 
 
