@@ -554,7 +554,13 @@ void lnf_update_exporter_stats(lnf_file_t *lnf_file, nffile_t *nffile) {
 	size_t size;
 	int i = 0;
 
-	size = sizeof(exporter_stats_record_t) + (lnf_file->num_exporters - 1 ) * sizeof(struct exporter_stat_s);
+	/* we will not prepare exporters structure if there are no exporters */
+	if (lnf_file->num_exporters == 0) {
+		return; 
+	}
+
+	/* exporter_stats_record_t contains first exporter_stat_s structure */
+	size = sizeof(exporter_stats_record_t) + (lnf_file->num_exporters - 1)  * sizeof(struct exporter_stat_s);
 	estats = malloc(size);
 
 	if (estats == NULL) {
@@ -617,6 +623,7 @@ void lnf_close(lnf_file_t *lnf_file) {
 	}
 
 	DisposeFile(lnf_file->nffile); 
+	free(lnf_file->nffile);
 
 	PackExtensionMapList(lnf_file->extension_map_list);
 	FreeExtensionMaps(lnf_file->extension_map_list);
@@ -1171,6 +1178,7 @@ void lnf_rec_clear(lnf_rec_t *rec) {
 
 	memset(rec->exporter, 0x0, sizeof(exporter_t));
 	memset(rec->sampler, 0x0, sizeof(sampler_t));
+	rec->flags = 0x0;
 
 	rec->exporter->info.version = LNF_DEFAULT_EXPORTER_VERSION;
 }
